api_endringer_1963: Test data for changes in municipality codes from 1963 onwards

api_endringer_1963R Documentation

Test data for changes in municipality codes from 1963 onwards

Description

A data.frame containing information about changes in municipality codes

Usage

api_endringer_1963

Format

An object of class data.frame with 1172 rows and 7 columns.


klassR documentation built on Aug. 21, 2026, 5:15 p.m.