api_endringer_2019: Test data for changes in municipality codes from 2019 onwards

api_endringer_2019R Documentation

Test data for changes in municipality codes from 2019 onwards

Description

A data.frame containing information about changes in municipality codes

Usage

api_endringer_2019

Format

An object of class data.frame with 444 rows and 7 columns.


klassR documentation built on Aug. 21, 2026, 5:15 p.m.