View source: R/find_equivalents.R
| find_equivalent_nodes | R Documentation |
Find the equivalent sets of a node at various dates
find_equivalent_nodes(node, dates, graph)
node |
The node that we're finding the equivalent sets of |
dates |
The dates that we want to find the equivalent sets in |
graph |
The graph that the nodes come from |
A named list of length(dates) containing the equivalent nodes for
each date. The names of the returned list are the dates provided in date,
coerced to character.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.