find_variant_to: Find the variant of a code corresponding to a change _to_ a...

View source: R/UpdateKlass-graph-build.R

find_variant_toR Documentation

Find the variant of a code corresponding to a change to a specific code.

Description

Find the variant of a code corresponding to a change to a specific code.

Usage

find_variant_to(x, changeOccurred, variants)

Arguments

x

The code that is being changed

changeOccurred

The date the change occurred

variants

The variants lookup-table.

Value

The variant corresponding to the code x at date changeOccurred.

See Also

find_variant_from()


klassR documentation built on Aug. 21, 2026, 5:15 p.m.