get_version: Get version number of a class given a date

View source: R/Klass_list.R

get_versionR Documentation

Get version number of a class given a date

Description

Get version number of a class given a date

Usage

get_version(classification = NULL, date = NULL, family = NULL, klassNr = FALSE)

GetVersion(klass = NULL, date = NULL, family = NULL, klassNr = FALSE)

Arguments

classification

Classification number

date

Date for version to be valid

family

Family ID number if a list of version number for all classes is desired

klassNr

True/False for whether to output classification numbers. Default = FALSE

klass

Deprecated; use classification instead.

Value

Number, vector or data frame with version numbers and calssification numbers if specified.

Examples

get_version(7)

klassR documentation built on Aug. 21, 2026, 5:15 p.m.

Related to get_version in klassR...