Given a graph and a node, determine if the node is a result of combinations of multiple codes.
is_combined(graph, node, compare_node = NULL)TRUE if the node is a combination of two or more nodes,
otherwise FALSE.
A graph generated by klass_graph.
A node as returned by klass_node or
V.
Optional. A node to compare node with when
determining whether node is combined. See details.
The function will attempt to reconcile nodes that have split and then later merged again when evaluating a node's combinedness.
If compare_node == NULL, a node is considered to be combined if more
than one node that does not itself have a parent (i.e. codes at the start
of a sequence of changes) contribute to node.
If compare_node != NULL, a node is considered to be combined if any
node that is not an ancestor of compare_node contributes to
node, i.e. all paths from node to the parents of node
pass through compare_node.