levelCheck: Check which level the input data/vector is

View source: R/checkLevel.R

levelCheckR Documentation

Check which level the input data/vector is

Description

The input level is calculated as the mode (most common) hierarchical level in the input vector.

Usage

levelCheck(x, klass_data)

Arguments

x
  • vector of character

klass_data
    • the right formatting to the classification levels

Value

The hierarchical level of the input data is returned.


klassR documentation built on Aug. 21, 2026, 5:15 p.m.

Related to levelCheck in klassR...